==> cmsmadesimple-1.6.4.tgz: cms/modules/FileManager/lang/ext/fi_FI.php <==
<?php
$lang['friendlyname'] = 'Tiedostonhallinta';
$lang['permission'] = 'Tiedostonhallinnan k&auml;ytt&ouml;';
$lang['permissionadvanced'] = 'Kehittyneet ominaisuudet tiedostonhallintamoduulissa';
$lang['moddescription'] = 'Tiedostojen ja kansioiden hallinta';
$lang['installed'] = 'Tiedostonhallinnan versio %s asennettu';
$lang['postinstall'] = 'Tiedostonhallinta asennettu';
$lang['uninstalled'] = 'Tiedostonhallinta poistettu';
$lang['really_uninstall'] = 'Haluatko varmasti poistaa tiedostonhallintamoduulin?';
$lang['upgraded'] = 'Tiedostonhallinta p&auml;ivitetty versioon %s';
$lang['fileview'] = 'Tiedoston&auml;kym&auml;';
$lang['switchtofileview'] = 'Vaihda tiedoston&auml;kym&auml;&auml;n';
$lang['settings'] = 'Asetukset';
$lang['savesettings'] = 'Tallenna asetukset';
$lang['filename'] = 'Tiedostonimi';
$lang['fileinfo'] = 'Tiedoston tiedot';
$lang['fileowner'] = 'Omistaja';
$lang['fileperms'] = 'Oikeudet';
$lang['filesize'] = 'Koko';
$lang['filedate'] = 'Pvm';
$lang['actions'] = 'Toiminnot';
$lang['delete'] = 'Poista';
$lang['notwritable'] = 'Vain luku';
$lang['filetoobig'] = 'on liian suuri. Siirto keskeytetty.';
$lang['unknown'] = 'Tuntematon';
$lang['fileoutsideuploads'] = 'Sinulla ei ole oikeuksia muuttaa uploads-hakemiston ulkopuolella olevia tiedostoja! (Se vaatii kehittyneit&auml; tiedostonhallintaoikeuksia)';
$lang['writable'] = 'Kirjoitettavissa';
$lang['writeprotected'] = 'Kirjoitussuojattu';
$lang['bytes'] = 'tavua';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'tiedostot';
$lang['bytesin'] = 'tavua sis&auml;&auml;n';
$lang['in'] = 'ajassa';
$lang['file'] = 'tiedosto';
$lang['fileno'] = 'Tiedosto nro';
$lang['subdirs'] = 'alihakemistot';
$lang['subdir'] = 'alihakemisto';
$lang['and'] = 'ja';
$lang['confirmsingledelete'] = 'oletko varma?';
$lang['confirmsingledirdelete'] = 'Oletko varma kansion poistosta?';
$lang['dirtreedeletesuccess'] = 'Kansio ja sen sis&auml;lt&ouml; on poistettu';
$lang['dirtreedeletefail'] = 'Poistossa tapahtui virhe! Jotain sis&auml;lt&ouml;&auml; on kuitenkin saattanut poistua!';
$lang['singlefiledeletesuccess'] = 'Tiedosto poistettu';
$lang['filedeletesuccess'] = 'on poistettu';
$lang['singlefiledeletefail'] = 'Virhe poistettaessa tiedostoa';
$lang['filedeletefail'] = ' ei poistettu virheen takia';
$lang['singledirdeletesuccess'] = 'Kansio poistettu';
$lang['singledirdeletefail'] = 'Virhe poistettaessa hakemistoa (onko hakemisto tyhj&auml;?)';
$lang['deleteselected'] = 'Poista valitut tiedostot';
$lang['confirmselected'] = 'Oletko varma?';
$lang['confirmdeleteselected'] = 'Oletko varma valittujen tiedostojen poistamisesta?';
$lang['deleteselectedcancelled'] = 'Valittujen tiedostojen poisto peruutettu';
$lang['recursetext'] = 'Alihakemistot sis&auml;lt&ouml;ineen';
$lang['nofilesselected'] = 'Ei valittuja tiedostoja';
$lang['moveselected'] = 'Siirr&auml; valitut tiedostot';
$lang['copyselected'] = 'Kopioi valitut tiedostot';
$lang['selecttargetdir'] = 'Valitse kohdehakemisto siirrolle/kopioinnille';
$lang['movedto'] = 'siirretty kansioon';
$lang['copiedto'] = 'kopioitu kansioon';
$lang['couldnotmove'] = 'ei voitu siirt&auml;&auml;';
$lang['couldnotcopy'] = 'ei voitu kopioida';
$lang['rename'] = 'Uudelleennime&auml;';
$lang['newname'] = 'Uusi nimi:';
$lang['renamesuccess'] = 'Tiedosto onnistuneeti uudelleennimetty';
$lang['renamefailure'] = 'Uudelleennime&auml;minen ep&auml;onnistui';
$lang['renamecancelled'] = 'Uudelleennime&auml;minen keskeytetty';
$lang['owner'] = 'Omistaja';
$lang['group'] = 'Ryhm&auml;';
$lang['others'] = 'Muut';
$lang['newpermissions'] = 'Uudet oikeudet:';
$lang['setpermissions'] = 'Aseta oikeudet:';
$lang['permissionstyle'] = 'Oikeuksien esitystapa';
$lang['rwxstyle'] = 'rwx-tyyli';
$lang['755style'] = '755-tyyli';
$lang['quickmode'] = 'Quick chmod (like 777)';
$lang['chmod'] = 'Muuta oikeudet';
$lang['chmodselected'] = 'Muuta valittujen tiedostojen oikeuksia';
$lang['chmodsuccess'] = 'Tiedoston oikeudet onnistuneesti muutettu';
$lang['chmodfailure'] = 'Tiedosto-oikeuksien muutos ep&auml;onnistui';
$lang['chmodcancelled'] = 'Tiedosto-oikeuksien muutos keskeytetty';
$lang['dirchmodfailmulti'] = 'Hakemisto-oikeuksien muuttaminen ep&auml;onnistui, silti oikeudet osalle sis&auml;ll&ouml;st&auml; ovat voineet muuttua.';
$lang['dirchmodsuccessmulti'] = 'Hakemistojen ja sis&auml;lt&ouml;jen oikeudet p&auml;ivitetty onnistuneesti';
$lang['dirchmodsuccess'] = 'Hakemiston oikeudet onnistuneesti vaihdettu';
$lang['dirchmodfailure'] = 'Hakemisto-oikeuksien muutos ep&auml;onnistui';
$lang['dirnotemptyconfirm'] = 'T&auml;m&auml; kansio ei ole tyhj&auml;. Haluatko varmasti poistaa kansion ja kaiken sen sis&auml;ll&ouml;n?';
$lang['dirtreedeletecancelled'] = 'Kansion poisto peruttu';
$lang['imsure'] = 'Olen varma';
$lang['cancel'] = 'Peruuta';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Lataa uusia tiedostoja';
$lang['unpackafterupload'] = 'Yrit&auml; purkaa tiedostoa latauksen j&auml;lkeen (tgz- ja zip-tiedostot)?';
$lang['uploadsuccess'] = 'ladattiin onnistuneesti';
$lang['uploadfail'] = 'lataus ep&auml;onnistui';
$lang['unpacksuccess'] = 'purettiin onnistuneesti';
$lang['unpackfail'] = 'virhe: ';
$lang['packfileopenfail'] = 'Ei voitu purkaa tiedostoa (pakkaustapaa ei tueta?)';
$lang['packfilewritefail'] = 'Ei voitu avata tiedostoa &amp;s kirjoitusta varten';
$lang['currentpath'] = 'Ty&ouml;hakemisto:';
$lang['newdirname'] = 'Luo uusi kansio: ';
$lang['newdirsuccess'] = 'Kansio luotu';
$lang['newdirfail'] = 'Kansion luonti ep&auml;onnistui';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Kuvakkeen koko';
$lang['smallicons'] = 'Pienet kuvakkeet';
$lang['largeicons'] = 'Suuret kuvakkeet';
$lang['thousanddelimiter'] = 'Tuhansien erotin';
$lang['none'] = 'Ei mit&auml;&auml;n';
$lang['showthumbnails'] = 'N&auml;yt&auml; pienoiskuvat';
$lang['showthumbnailshelp'] = 'Valinta n&auml;ytt&auml;&auml; kuvatiedostojen pienoiskuvat, jos sellaiset on olemassa ja piilottaa pienoiskuvan listauksesta. Jos et valitse t&auml;t&auml;, n&auml;ytet&auml;&auml;n kaikki tiedostot sellaisenaan.';
$lang['uploadfilesto'] = 'Ladataan tiedostoja sijaintiin:';
$lang['uploadview'] = 'Lataa tiedostoja';
$lang['uploadboxes'] = 'lataus laatikoita';
$lang['nothinguploaded'] = 'Mit&auml;&auml;n ei ladattu';
$lang['unsupportedarchive'] = 'Pakkausmuoto on tuntematon';
$lang['uploadmethod'] = 'Lataustapa';
$lang['uploaderstandard'] = 'Normaali html input -kentt&auml; (sallii purkamisen)';
$lang['enableadvanced'] = 'Ota k&auml;ytt&ouml;&ouml;n kehittyneet ominaisuudet (jos sallittu)';
$lang['advancedhelp'] = 'Sallii selailun koko CMSMS kansiossa, ei vain /upload/. (vain jos tiedosto oikeudet sallivat)';
$lang['showhiddenfileshelp'] = 'Vaikuttaa vain edistyneess&auml; moodissa';
$lang['showhiddenfiles'] = 'N&auml;yt&auml; piilotiedostot';
$lang['settingsconfirmsingledelete'] = 'Varmista yksitt&auml;isen tiedoston poisto';
$lang['settingssaved'] = 'Asetukset talletettu';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions, eventually and hopefully replacing the rather aged builtin file management</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. While the old filemanager is still in there you should select the one furthest down in the menu.</p>';
$lang['utma'] = '156861353.1959547193.1213865783.1215201910.1215340163.28';
$lang['utmz'] = '156861353.1214056345.10.4.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/forum/forum.php|utmcmd=referral';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/fi_FI.php <==
<?php
$lang['friendlyname'] = 'Tiedostonhallinta';
$lang['permission'] = 'Tiedostonhallinnan k&auml;ytt&ouml;';
$lang['permissionadvanced'] = 'Kehittyneet ominaisuudet tiedostonhallintamoduulissa';
$lang['moddescription'] = 'Tiedostojen ja kansioiden hallinta';
$lang['installed'] = 'Tiedostonhallinnan versio %s asennettu';
$lang['postinstall'] = 'Tiedostonhallinta asennettu';
$lang['uninstalled'] = 'Tiedostonhallinta poistettu';
$lang['really_uninstall'] = 'Haluatko varmasti poistaa tiedostonhallintamoduulin?';
$lang['upgraded'] = 'Tiedostonhallinta p&auml;ivitetty versioon %s';
$lang['fileview'] = 'Tiedoston&auml;kym&auml;';
$lang['switchtofileview'] = 'Vaihda tiedoston&auml;kym&auml;&auml;n';
$lang['settings'] = 'Asetukset';
$lang['savesettings'] = 'Tallenna asetukset';
$lang['filename'] = 'Tiedostonimi';
$lang['fileinfo'] = 'Tiedoston tiedot';
$lang['fileowner'] = 'Omistaja';
$lang['fileperms'] = 'Oikeudet';
$lang['filesize'] = 'Koko';
$lang['filedate'] = 'Pvm';
$lang['actions'] = 'Toiminnot';
$lang['delete'] = 'Poista';
$lang['notwritable'] = 'Vain luku';
$lang['filetoobig'] = 'on liian suuri. Siirto keskeytetty.';
$lang['unknown'] = 'Tuntematon';
$lang['fileoutsideuploads'] = 'Sinulla ei ole oikeuksia muuttaa uploads-hakemiston ulkopuolella olevia tiedostoja! (Se vaatii monipuolisempia tiedostonhallintaoikeuksia)';
$lang['writable'] = 'Kirjoitettavissa';
$lang['writeprotected'] = 'Kirjoitussuojattu';
$lang['bytes'] = 'tavua';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'tiedostot';
$lang['bytesin'] = 'tavua sis&auml;&auml;n';
$lang['in'] = 'ajassa';
$lang['file'] = 'tiedosto';
$lang['fileno'] = 'Tiedosto nro';
$lang['subdirs'] = 'alihakemistot';
$lang['subdir'] = 'alihakemisto';
$lang['and'] = 'ja';
$lang['confirmsingledelete'] = 'oletko varma?';
$lang['confirmsingledirdelete'] = 'Oletko varma kansion poistosta?';
$lang['dirtreedeletesuccess'] = 'Kansio ja sen sis&auml;lt&ouml; on poistettu';
$lang['dirtreedeletefail'] = 'Poistossa tapahtui virhe! Jotain sis&auml;lt&ouml;&auml; on kuitenkin saattanut poistua!';
$lang['singlefiledeletesuccess'] = 'Tiedosto poistettu';
$lang['filedeletesuccess'] = 'on poistettu';
$lang['singlefiledeletefail'] = 'Virhe poistettaessa tiedostoa';
$lang['filedeletefail'] = ' ei poistettu virheen takia';
$lang['singledirdeletesuccess'] = 'Kansio poistettu';
$lang['singledirdeletefail'] = 'Virhe poistettaessa hakemistoa (onko hakemisto tyhj&auml;?)';
$lang['deleteselected'] = 'Poista valitut tiedostot';
$lang['confirmselected'] = 'Oletko varma?';
$lang['confirmdeleteselected'] = 'Oletko varma valittujen tiedostojen poistamisesta?';
$lang['deleteselectedcancelled'] = 'Valittujen tiedostojen poisto peruutettu';
$lang['recursetext'] = 'Alihakemistot sis&auml;lt&ouml;ineen';
$lang['nofilesselected'] = 'Ei valittuja tiedostoja';
$lang['moveselected'] = 'Siirr&auml; valitut tiedostot';
$lang['copyselected'] = 'Kopioi valitut tiedostot';
$lang['selecttargetdir'] = 'Valitse kohdehakemisto siirrolle/kopioinnille';
$lang['movedto'] = 'siirretty kansioon';
$lang['copiedto'] = 'kopioitu kansioon';
$lang['couldnotmove'] = 'ei voitu siirt&auml;&auml;';
$lang['couldnotcopy'] = 'ei voitu kopioida';
$lang['rename'] = 'Uudelleennime&auml;';
$lang['newname'] = 'Uusi nimi:';
$lang['renamesuccess'] = 'Tiedosto onnistuneeti uudelleennimetty';
$lang['renamefailure'] = 'Uudelleennime&auml;minen ep&auml;onnistui';
$lang['renamecancelled'] = 'Uudelleennime&auml;minen keskeytetty';
$lang['owner'] = 'Omistaja';
$lang['group'] = 'Ryhm&auml;';
$lang['others'] = 'Muut';
$lang['newpermissions'] = 'Uudet oikeudet:';
$lang['setpermissions'] = 'Aseta oikeudet:';
$lang['permissionstyle'] = 'Oikeuksien esitystapa';
$lang['rwxstyle'] = 'rwx-tyyli';
$lang['755style'] = '755-tyyli';
$lang['quickmode'] = 'Nopea chmod (kuten 777)';
$lang['chmod'] = 'Muuta oikeudet';
$lang['chmodselected'] = 'Muuta valittujen tiedostojen oikeuksia';
$lang['chmodsuccess'] = 'Tiedoston oikeudet onnistuneesti muutettu';
$lang['chmodfailure'] = 'Tiedosto-oikeuksien muutos ep&auml;onnistui';
$lang['chmodcancelled'] = 'Tiedosto-oikeuksien muutos keskeytetty';
$lang['dirchmodfailmulti'] = 'Hakemisto-oikeuksien muuttaminen ep&auml;onnistui, silti oikeudet osalle sis&auml;ll&ouml;st&auml; ovat voineet muuttua.';
$lang['dirchmodsuccessmulti'] = 'Hakemistojen ja sis&auml;lt&ouml;jen oikeudet p&auml;ivitetty onnistuneesti';
$lang['dirchmodsuccess'] = 'Hakemiston oikeudet onnistuneesti vaihdettu';
$lang['dirchmodfailure'] = 'Hakemisto-oikeuksien muutos ep&auml;onnistui';
$lang['dirnotemptyconfirm'] = 'T&auml;m&auml; kansio ei ole tyhj&auml;. Haluatko varmasti poistaa kansion ja kaiken sen sis&auml;ll&ouml;n?';
$lang['dirtreedeletecancelled'] = 'Kansion poisto peruttu';
$lang['imsure'] = 'Olen varma';
$lang['cancel'] = 'Peruuta';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = 'Lataa uusia tiedostoja';
$lang['unpackafterupload'] = 'Yrit&auml; purkaa tiedostoa latauksen j&auml;lkeen (tgz- ja zip-tiedostot)?';
$lang['uploadsuccess'] = 'ladattiin onnistuneesti';
$lang['uploadfail'] = 'lataus ep&auml;onnistui';
$lang['unpacksuccess'] = 'purettiin onnistuneesti';
$lang['unpackfail'] = 'virhe: ';
$lang['packfileopenfail'] = 'Ei voitu purkaa tiedostoa (pakkaustapaa ei tueta?)';
$lang['packfilewritefail'] = 'Ei voitu avata tiedostoa &amp;s kirjoitusta varten';
$lang['containsillegalchars'] = 'Tiedostonimi sis&auml;lt&auml;&auml; yhden tai useamman kielletyn merkin (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Ty&ouml;hakemisto:';
$lang['newdirname'] = 'Luo uusi kansio: ';
$lang['newdirsuccess'] = 'Kansio luotu';
$lang['newdirfail'] = 'Kansion luonti ep&auml;onnistui';
$lang['invalidnewdir'] = 'Uuden hakemiston nimi ei voi sis&auml;lt&auml;&auml; merkkej&auml; kuten /, \ ja &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s';
$lang['iconsize'] = 'Kuvakkeen koko';
$lang['smallicons'] = 'Pienet kuvakkeet';
$lang['largeicons'] = 'Suuret kuvakkeet';
$lang['thousanddelimiter'] = 'Tuhansien erotin';
$lang['none'] = 'Ei mit&auml;&auml;n';
$lang['space'] = 'v&auml;lily&ouml;nti';
$lang['showthumbnails'] = 'N&auml;yt&auml; pienoiskuvat';
$lang['showthumbnailshelp'] = 'Valinta n&auml;ytt&auml;&auml; kuvatiedostojen pienoiskuvat, jos sellaiset on olemassa ja piilottaa pienoiskuvan listauksesta. Jos et valitse t&auml;t&auml;, n&auml;ytet&auml;&auml;n kaikki tiedostot sellaisenaan.';
$lang['uploadfilesto'] = 'Ladataan tiedostoja sijaintiin:';
$lang['uploadview'] = 'Lataa tiedostoja';
$lang['uploadboxes'] = 'lataus laatikoita';
$lang['nothinguploaded'] = 'Mit&auml;&auml;n ei ladattu';
$lang['unsupportedarchive'] = 'Pakkausmuoto on tuntematon';
$lang['uploadmethod'] = 'Lataustapa';
$lang['uploaderstandard'] = 'Normaali html input -kentt&auml; (sallii purkamisen)';
$lang['enableadvanced'] = 'Ota k&auml;ytt&ouml;&ouml;n kehittyneet ominaisuudet (jos sallittu)';
$lang['advancedhelp'] = 'Sallii selailun koko CMSMS kansiossa, ei vain /upload/. (vain jos tiedosto oikeudet sallivat)';
$lang['showhiddenfileshelp'] = 'Vaikuttaa vain edistyneess&auml; moodissa';
$lang['showhiddenfiles'] = 'N&auml;yt&auml; piilotiedostot';
$lang['settingsconfirmsingledelete'] = 'Varmista yksitt&auml;isen tiedoston poisto';
$lang['settingssaved'] = 'Asetukset talletettu';
$lang['help'] = '		<h3>Mit&auml; t&auml;m&auml; tekee?</h3>
		<p>T&auml;m&auml; moduuli tarjoaa tiedostonhallinta toimintoja, joka korvaa toivottavasti vanhentuneen sis&auml;&auml;nrakennetun tiedostonhallinnan.</p>
		<h3>Kuinka k&auml;yt&auml;n sit&auml;?</h3>
		<p>Valitse se sis&auml;lt&ouml;valikosta hallintapaneelissa. Vaikka vanhempi tiedostonhallinta on edelleen olemassa, sinun kannattaa valita valikon alimmainen.</p>';
$lang['utma'] = '156861353.572491444.1274267548.1274275175.1274281846.4';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1274270099.2.2.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
$lang['qca'] = 'P0-1477326709-1274267548700';
$lang['utmb'] = '156861353';
?>
